==> webkit2gtk_2.46.1.orig.tar.xz: webkitgtk-2.46.1/Tools/TestWebKitAPI/Utilities.cpp <==
/*
 * Copyright (C) 2017 Igalia S.L.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"
#include "Utilities.h"

#include <wtf/RunLoop.h>

namespace TestWebKitAPI::Util {

#if !PLATFORM(COCOA)

void run(bool* done)
{
    while (!*done)
        RunLoop::current().cycle();
}

void spinRunLoop(uint64_t count)
{
    while (count--)
        RunLoop::current().cycle();
}

bool runFor(bool* done, Seconds duration)
{
    ApproximateTime start = ApproximateTime::now();
    while (!*done) {
        if (ApproximateTime::now() - start > duration)
            return false;
        RunLoop::current().cycle();
    }
    return true;
}

void runFor(Seconds duration)
{
    RunLoop::current().dispatchAfter(duration, [] {
        RunLoop::current().stop();
    });
    RunLoop::current().run();
}

#endif

}

==> webkit2gtk_2.48.5.orig.tar.xz: webkitgtk-2.48.5/Tools/TestWebKitAPI/Utilities.cpp <==
/*
 * Copyright (C) 2017 Igalia S.L.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"
#include "Utilities.h"

#include <wtf/RunLoop.h>

namespace TestWebKitAPI::Util {

#if !PLATFORM(COCOA)

void run(bool* done)
{
    while (!*done)
        RunLoop::current().cycle();
}

void spinRunLoop(uint64_t count)
{
    while (count--)
        RunLoop::current().cycle();
}

bool runFor(bool* done, Seconds duration)
{
    ApproximateTime start = ApproximateTime::now();
    while (!*done) {
        if (ApproximateTime::now() - start > duration)
            return false;
        RunLoop::current().cycle();
    }
    return true;
}

void runFor(Seconds duration)
{
    RunLoop::protectedCurrent()->dispatchAfter(duration, [] {
        RunLoop::current().stop();
    });
    RunLoop::current().run();
}

#endif

}
